@@ -8,7 +8,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw( isleap );
-our $VERSION = ( qw'$Revision: 1.02 $' )[1];
+our $VERSION = ( qw'$Revision: 1.3 $' )[1];
 
 =head1 NAME
 
@@ -36,9 +36,10 @@ Returns 1 in a leap year, 0 otherwise.
 
 sub isleap {
     my ($year) = @_;
-    return 1 if ( ($year % 4 == 0) &&
-        ( ($year % 100) || ($year % 400 == 0) ) );
-    return 0;
+    return 1 if (( $year % 400 ) == 0 ); # 400's are leap
+    return 0 if (( $year % 100 ) == 0 ); # Other centuries are not
+    return 1 if (( $year % 4 ) == 0 ); # All other 4's are leap
+    return 0; # Everything else is not
 }
 
 1;
@@ -48,6 +49,10 @@ sub isleap {
 =head1 HISTORY
 
     $Log: Leapyear.pm,v $
+    Revision 1.3  2001/07/24 15:59:29  rbowen
+    Changed the leapyear algorithm to be a little more readable. Moved
+    tests to Test::More.
+
     Revision 1.2  2001/06/04 03:48:34  rbowen
     The readme file was apparently copied over from another project. Oops.
 
